==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebRowSelectorTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowSelectorTemplateDetailsDescriptionMetadata } from "./WebRowSelectorTemplateDetailsDescriptionMetadata";
import { WebRowSelectorTemplateContextDescription } from "./WebRowSelectorTemplateContextDescription";
/**
 * @hidden
 */
var WebRowSelectorTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowSelectorTemplateContextDescriptionMetadata, _super);
    function WebRowSelectorTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowSelectorTemplateContextDescriptionMetadata.b = function (a) {
        if (WebRowSelectorTemplateContextDescriptionMetadata.a == null) {
            WebRowSelectorTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowSelectorTemplateContextDescriptionMetadata.c(WebRowSelectorTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebRowSelectorTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebRowSelectorTemplateContextDescriptionMetadata.a);
        WebRowSelectorTemplateDetailsDescriptionMetadata.d(a);
    };
    WebRowSelectorTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RowSelectorTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "ExportedType:WebRowSelectorTemplateDetails");
    };
    WebRowSelectorTemplateContextDescriptionMetadata.d = function (a) {
        WebRowSelectorTemplateContextDescriptionMetadata.b(a);
        a.ad("WebRowSelectorTemplateContext", function () { return new WebRowSelectorTemplateContextDescription(); });
        a.ac("WebRowSelectorTemplateContext", WebRowSelectorTemplateContextDescriptionMetadata.a);
    };
    WebRowSelectorTemplateContextDescriptionMetadata.$t = markType(WebRowSelectorTemplateContextDescriptionMetadata, 'WebRowSelectorTemplateContextDescriptionMetadata');
    WebRowSelectorTemplateContextDescriptionMetadata.a = null;
    return WebRowSelectorTemplateContextDescriptionMetadata;
}(Base));
export { WebRowSelectorTemplateContextDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebRowSelectorTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowSelectorTemplateDetailsDescriptionMetadata } from "./WebRowSelectorTemplateDetailsDescriptionMetadata";
import { WebRowSelectorTemplateContextDescription } from "./WebRowSelectorTemplateContextDescription";
/**
 * @hidden
 */
var WebRowSelectorTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowSelectorTemplateContextDescriptionMetadata, _super);
    function WebRowSelectorTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowSelectorTemplateContextDescriptionMetadata.b = function (a) {
        if (WebRowSelectorTemplateContextDescriptionMetadata.a == null) {
            WebRowSelectorTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowSelectorTemplateContextDescriptionMetadata.c(WebRowSelectorTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebRowSelectorTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebRowSelectorTemplateContextDescriptionMetadata.a);
        WebRowSelectorTemplateDetailsDescriptionMetadata.d(a);
    };
    WebRowSelectorTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RowSelectorTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "ExportedType:WebRowSelectorTemplateDetails");
    };
    WebRowSelectorTemplateContextDescriptionMetadata.d = function (a) {
        WebRowSelectorTemplateContextDescriptionMetadata.b(a);
        a.ae("WebRowSelectorTemplateContext", function () { return new WebRowSelectorTemplateContextDescription(); });
        a.ad("WebRowSelectorTemplateContext", WebRowSelectorTemplateContextDescriptionMetadata.a);
    };
    WebRowSelectorTemplateContextDescriptionMetadata.$t = markType(WebRowSelectorTemplateContextDescriptionMetadata, 'WebRowSelectorTemplateContextDescriptionMetadata');
    WebRowSelectorTemplateContextDescriptionMetadata.a = null;
    return WebRowSelectorTemplateContextDescriptionMetadata;
}(Base));
export { WebRowSelectorTemplateContextDescriptionMetadata };
